@@ -12,13 +12,13 @@
 #' \donttest{
 #' get_committee('C00553560', 2016)
 #' }
-get_committee <- function(FEC_ID, cycle=2018, myAPI_Key){
+get_committee <- function(FEC_ID, cycle=2018, page = 1, myAPI_Key){
   API = 'campaign-finance'
   if(!validate_cycle(cycle))
     stop("Incorrect cycle")
   if(is.character(FEC_ID)){
     query <- sprintf("%s/committees/%s.json", cycle,FEC_ID)
-    pp_query(query, API, myAPI_Key = myAPI_Key)
+    pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
   } else {stop("FEC_ID has to be character")}
 }
 
