@@ -14,12 +14,12 @@
 #' get_committee_electioneering_communications(2016, 'C30002034')
 #'
 #' }
-get_committee_electioneering_communications <- function(cycle=2018, FEC_ID, myAPI_Key){
+get_committee_electioneering_communications <- function(cycle=2018, FEC_ID, page = 1, myAPI_Key){
   API = 'campaign-finance'
   if(!validate_cycle(cycle))
     stop("Incorrect cycle")
   if(is.character(FEC_ID)){
     query <- sprintf("%s/committees/%s/electioneering_communications.json", cycle, FEC_ID)
-    pp_query(query, API, myAPI_Key = myAPI_Key)
+    pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
   } else {stop("FEC_ID has to be character")}
 }
