@@ -12,7 +12,7 @@
 #' \donttest{
 #' get_electronic_filing_form_types(2016)
 #' }
-get_electronic_filing_form_types <- function(cycle=2018, myAPI_Key){
+get_electronic_filing_form_types <- function(cycle=2018, page = 1, myAPI_Key){
   API = 'campaign-finance'
   if(!validate_cycle(cycle)){
     stop("Incorrect cycle")
@@ -21,5 +21,5 @@ get_electronic_filing_form_types <- function(cycle=2018, myAPI_Key){
     stop("Incorrect cycle: the electronic filings are 2001-forward")
   }
   query <- sprintf("%s/filings/types.json", cycle)
-  pp_query(query, API, myAPI_Key = myAPI_Key)
+  pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
 }
