@@ -2,7 +2,7 @@
 #'
 #' To get a list of 20 upcoming Senate or House committee meetings, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/{congress}/{chamber}/committees/{committee-id}/hearings.json
 #'
-#' @param congress 114-115
+#' @param congress 114-116
 #' @param chamber house or senate
 #' @param committee_id Optional committee abbreviation, for example HSAG. Use the full committees response to find abbreviations.
 #' @inheritParams get_new_members
@@ -16,10 +16,10 @@
 #' get_hearing_specific_committee(115, 'house', 
 #' lists_of_committees(115, "senate")$results[[1]]$committees[[1]]$id)
 #' }
-get_hearing_specific_committee <- function(congress, chamber, committee_id, myAPI_Key){
+get_hearing_specific_committee <- function(congress, chamber, committee_id, page = 1, myAPI_Key){
   API = 'congress'
-  if(!congress %in% 114:115){
-    stop("Incorrect congress, should be 110 until 115")
+  if(!congress %in% 114:cMaxCongress){
+    stop("Incorrect congress, should be between 110 and ",cMaxCongress)
   }
   if(!chamber %in% c('house', 'senate')){
     stop("Incorrect chamber. Should be \'senate\' or \'house'\ , lowercase")
@@ -28,6 +28,6 @@ get_hearing_specific_committee <- function(congress, chamber, committee_id, myAP
     stop("committee_id has to be character")
   } else {
     query <- sprintf("%s/%s/committees/%s/hearings.json", congress, chamber, committee_id)
-    pp_query(query, API, myAPI_Key = myAPI_Key)
+    pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
     }
 }
\ No newline at end of file
