@@ -13,15 +13,15 @@
 #' \donttest{
 #' get_independent_expenditure_support_candidate(2016, FEC_ID ='P00003392')
 #' }
-get_independent_expenditure_support_candidate<- function(cycle=2018, FEC_ID, myAPI_Key){
+get_independent_expenditure_support_candidate<- function(cycle=2018, FEC_ID, page = 1, myAPI_Key){
   API = 'campaign-finance'
   if(!validate_cycle(cycle)){
     stop("Incorrect cycle")
   }
   if(cycle < 2009){
-    stop("Incorrect cycle: independent expenditures are from 2009-present")}
+    stop("Incorrect cycle: independent expenditures are from 2009 to present")}
   if(is.character(FEC_ID)){
     query <- sprintf("%s/candidates/%s/independent_expenditures.json", cycle, FEC_ID)
-    pp_query(query, API, myAPI_Key = myAPI_Key)
+    pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
   } else {stop("FEC_ID has to be character")}
 }
