@@ -12,13 +12,13 @@
 #' \donttest{
 #' get_independent_expenditure_support_presidential_candidate(2016)
 #' }
-get_independent_expenditure_support_presidential_candidate<- function(cycle=2018 , myAPI_Key){
+get_independent_expenditure_support_presidential_candidate<- function(cycle=2018 , page = 1, myAPI_Key){
   API = 'campaign-finance'
   if(!validate_cycle(cycle)){
     stop("Incorrect cycle")
   }
   if(cycle < 2009){
-    stop("Incorrect cycle: independent expenditures are from 2009-present")}
+    stop("Incorrect cycle: independent expenditures are from 2009 to present")}
   query <- sprintf("%s/president/independent_expenditures.json", cycle)
-  pp_query(query, API, myAPI_Key = myAPI_Key)
+  pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
 }
