@@ -14,7 +14,7 @@
 #' \donttest{
 #' get_quarter_office_expenses_house_member('A000374', 2017, 4)
 #' }
-get_quarter_office_expenses_house_member <- function(member_id, year, quarter, myAPI_Key){
+get_quarter_office_expenses_house_member <- function(member_id, year, quarter, page = 1, myAPI_Key){
   API = 'congress'
   if(!quarter %in% 1:4){
     stop("Incorret quarter. Has to be 1, 2, 3 or 4.")
@@ -26,6 +26,6 @@ get_quarter_office_expenses_house_member <- function(member_id, year, quarter, m
     stop("member_id has to be character")
   } else {if(2008 < year & year < 2018){
     query <- sprintf("members/%s/office_expenses/%s/%s.json", member_id, year, quarter)
-    pp_query(query, API, myAPI_Key = myAPI_Key)}
+    pp_query(query, API, page = page, myAPI_Key = myAPI_Key)}
     }
 }
