@@ -14,7 +14,7 @@
 #' \donttest{
 #' get_recent_congressional_statements_by_date(2017, '05', '08')
 #' }
-get_recent_congressional_statements_by_date <- function(year, month, day, myAPI_Key){
+get_recent_congressional_statements_by_date <- function(year, month, day, page = 1, myAPI_Key){
   API = 'congress'
   if(nchar(year)!=4){
     stop("Incorrect year. Year should be four-digit year")  
@@ -22,5 +22,5 @@ get_recent_congressional_statements_by_date <- function(year, month, day, myAPI_
   sep = '-'
   date <- paste0(year, sep, month, sep, day)
   query <- sprintf("statements/date/%s.json", date)
-  pp_query(query, API, myAPI_Key = myAPI_Key)
+  pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
 }
\ No newline at end of file
