@@ -13,11 +13,11 @@
 #' get_recent_electioneering_communications(2016)
 #'
 #' }
-get_recent_electioneering_communications <- function(cycle=2018, myAPI_Key){
+get_recent_electioneering_communications <- function(cycle=2018, page = 1, myAPI_Key){
   API = 'campaign-finance'
   if(!validate_cycle(cycle)){
     stop("Incorrect cycle")
   }
   query <- sprintf("%s/electioneering_communications.json", cycle)
-  pp_query(query, API, myAPI_Key = myAPI_Key)
+  pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
 }
