@@ -12,12 +12,12 @@
 #' \donttest{
 #' get_recent_late_contributions(2016)
 #' }
-get_recent_late_contributions <- function(cycle=2018, myAPI_Key){
+get_recent_late_contributions <- function(cycle=2018, page = 1, myAPI_Key){
   API = 'campaign-finance'
   if(!validate_cycle(cycle))
     stop("Incorrect cycle")
   if(cycle<2010)
     stop("Cycle must be even-numbered year between 2010 and 2018")
   query <- sprintf("%s/contributions/48hour.json", cycle)
-  pp_query(query, API, myAPI_Key = myAPI_Key)
+  pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
 }
