@@ -2,7 +2,7 @@
 #'
 #' To get lists of presidential nominations for civilian positions,, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/{congress}/nominees/{type}.json
 #'
-#' @param congress 107-115
+#' @param congress 107-116
 #' @param type received, updated, confirmed, withdrawn
 #' @inheritParams get_new_members
 #'
@@ -13,14 +13,14 @@
 #' \donttest{
 #' get_recent_nominations_by_category(115, 'confirmed')
 #' }
-get_recent_nominations_by_category <- function(congress, type, myAPI_Key){
+get_recent_nominations_by_category <- function(congress, type, page = 1, myAPI_Key){
   API = 'congress'
-  if(!congress %in% 96:115){
-    stop("Incorrect congress, should be 107-115")
+  if(!congress %in% 107:cMaxCongress){
+    stop("Incorrect congress, should be between 107 and ",cMaxCongress)
   }
   if(!type %in% c('received', 'updated', 'confirmed', 'withdrawn')){
     stop("Incorrect category. Should be \'received\', \'updated\', \'confirmed\' or \'withdrawn\', lowercase")
   }
   query <- sprintf("%s/nominees/%s.json", congress, type)
-  pp_query(query, API, myAPI_Key = myAPI_Key)
+  pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
 }
\ No newline at end of file
