@@ -1,8 +1,8 @@
 #' Get Recent Official Communications by Category
 #'
-#' To get lists of official communications to Congress from the president, executive branch agencies and state legislatures to congressional committees, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/{congress}/communications/category/{category}.json
+#' Get lists of official communications to Congress from the president, executive branch agencies and state legislatures to congressional committees.
 #'
-#' @param congress 114-115 for House, 96-115 for Senate
+#' @param congress 114-116 for House, 96-116 for Senate
 #' @param category ec, pm, pom
 #' @inheritParams get_new_members
 #'
@@ -13,14 +13,14 @@
 #' \donttest{
 #' get_recent_official_communications_by_category(115, 'pm')
 #' }
-get_recent_official_communications_by_category <- function(congress, category, myAPI_Key){
+get_recent_official_communications_by_category <- function(congress, category, page = 1, myAPI_Key){
   API = 'congress'
-  if(!congress %in% 96:115){
-    stop("Incorrect congress, should be 110-115 for House or 96-115 for Senate")
+  if(!congress %in% 96:cMaxCongress){
+    stop("Incorrect congress, should be between 110 and ",cMaxCongress," for House. Between 96 and ",cMaxCongress," for Senate")
   }
   if(!category %in% c('ec', 'pm', 'pom')){
     stop("Incorrect category. Should be \'ec\', \'pm\' or \'pom\', lowercase")
   }
   query <- sprintf("%s/communications/category/%s.json", congress, category)
-  pp_query(query, API, myAPI_Key = myAPI_Key)
+  pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
 }
\ No newline at end of file
