@@ -2,7 +2,7 @@
 #'
 #' To get Senate votes on presidential nominations. HTTP Request: GET https://api.propublica.org/congress/v1/{congress}/nominations.json
 #'
-#' @param congress 		101-115
+#' @param congress 		101-116
 #' @inheritParams get_new_members
 #'
 #' @return List of returned JSON from endpoint that retrieves Senate votes on presidential nominations
@@ -12,11 +12,11 @@
 #' \donttest{
 #' get_senate_nomination_votes(114)
 #' }
-get_senate_nomination_votes <- function(congress, myAPI_Key){
+get_senate_nomination_votes <- function(congress, page = 1, myAPI_Key){
   API = 'congress'
-  if(!congress %in% 101:115){
-    stop("Incorrect congress, should be 101-115")
+  if(!congress %in% 101:cMaxCongress){
+    stop("Incorrect congress, should be between 101 and", cMaxCongress)
   }
   query <- sprintf("%s/nominations.json", congress)
-  pp_query(query, API, myAPI_Key = myAPI_Key)
+  pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
 }
\ No newline at end of file
