@@ -13,10 +13,10 @@
 #' \donttest{
 #' get_specific_bill_subject('meat')
 #' }
-get_specific_bill_subject <- function(subject, myAPI_Key){
+get_specific_bill_subject <- function(subject, page = 1, myAPI_Key){
   API = 'congress'
   if(is.character(query)){
     query <- sprintf("bills/subjects/%s.json", subject)
-    pp_query(query, API, myAPI_Key = myAPI_Key)
+    pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
   } else {stop("query has to be character, 	a word or phrase to search")}
 }
