@@ -2,7 +2,7 @@
 #'
 #' To get information about a single Senate or House committee, including the members of that committee, use the following function. The committee ids can be found in the committee list responses. HTTP Request: GET https://api.propublica.org/congress/v1/{congress}/{chamber}/committees/{committee-id}.json
 #'
-#' @param congress 110-115
+#' @param congress 110-116
 #' @param chamber house, senate or joint
 #' @param committee_id Committee abbreviation, for example HSAG. Use the full committees response to find abbreviations.
 #' @inheritParams get_new_members
@@ -17,14 +17,14 @@
 #' 
 #' get_specific_committee(115, "senate", "SSAF")
 #' }
-get_specific_committee <- function(congress, chamber, committee_id, myAPI_Key){
+get_specific_committee <- function(congress, chamber, committee_id, page = 1, myAPI_Key){
   API = 'congress'
-  if(!congress %in% 110:115){
-    stop("Incorrect congress, should be 110 until 115")
+  if(!congress %in% 110:cMaxCongress){
+    stop("Incorrect congress, should be between 110 and ",cMaxCongress)
   }
   if(!chamber %in% c('house', 'senate', 'both')){
     stop("Incorrect chamber. Should be \'senate\', \'house'\ or \'both\', lowercase")
   }
   query <- sprintf("%s/%s/committees/%s.json", congress, chamber, committee_id)
-  pp_query(query, API, myAPI_Key = myAPI_Key)
+  pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
 }
\ No newline at end of file
