@@ -11,8 +11,8 @@
 #' \donttest{
 #' get_state_party_counts()
 #' }
-get_state_party_counts <- function(myAPI_Key){
+get_state_party_counts <- function(page = 1, myAPI_Key){
   API = 'congress'
   query <- "states/members/party.json"
-  pp_query(query, API, myAPI_Key = myAPI_Key)
+  pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
 }
\ No newline at end of file
