@@ -14,7 +14,7 @@
 #' \donttest{
 #' get_top20_candidate_of_FinancialCategory('pac-total', 2016)
 #' }
-get_top20_candidate_of_FinancialCategory <- function(category, cycle=2018, myAPI_Key){
+get_top20_candidate_of_FinancialCategory <- function(category, cycle=2018, page = 1, myAPI_Key){
   API = 'campaign-finance'
   if(!validate_cycle(cycle))
     stop("Incorrect cycle")
@@ -22,7 +22,7 @@ get_top20_candidate_of_FinancialCategory <- function(category, cycle=2018, myAPI
                                               , 'end-cash', 'individual-total', 'pac-total', 'receipts-total',
                                               'refund-total')){
     query <- sprintf("%s/candidates/leaders/%s.json", cycle,category)
-    pp_query(query, API,  myAPI_Key = myAPI_Key)
+    pp_query(query, API,  page = page, myAPI_Key = myAPI_Key)
   } else stop("Incorrect Category")
     
 }
