@@ -2,7 +2,7 @@
 #'
 #' To get a list of Senate, House or joint committees, including their subcommittees, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/{congress}/{chamber}/committees.json
 #'
-#' @param congress 110-115
+#' @param congress 110-116
 #' @param chamber house, senate or joint
 #' @inheritParams get_new_members
 #'
@@ -13,14 +13,14 @@
 #' \donttest{
 #' lists_of_committees(115, "senate")
 #' }
-lists_of_committees <- function(congress, chamber, myAPI_Key){
+lists_of_committees <- function(congress, chamber, page = 1, myAPI_Key){
   API = 'congress'
-  if(!congress %in% 110:115){
-    stop("Incorrect congress, should be 110 until 115")
+  if(!congress %in% 110:cMaxCongress){
+    stop("Incorrect congress, should be between 110 and ", cMaxCongress)
   }
   if(!chamber %in% c('house', 'senate', 'both')){
     stop("Incorrect chamber. Should be \'senate\', \'house'\ or \'both\', lowercase")
   }
   query <- sprintf("%s/%s/committees.json", congress, chamber)
-  pp_query(query, API, myAPI_Key = myAPI_Key)
+  pp_query(query, API, page = page, myAPI_Key = myAPI_Key)
 }
\ No newline at end of file
